@@ -67,6 +67,23 @@ sub new {
 		0,
 	);
 
+	$self->{m_listBox1} = Wx::ListBox->new(
+		$self,
+		-1,
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		[ ],
+		0,
+	);
+
+	$self->{m_listCtrl1} = Wx::ListCtrl->new(
+		$self,
+		-1,
+		Wx::wxDefaultPosition,
+		Wx::wxDefaultSize,
+		Wx::wxLC_ICON,
+	);
+
 	my $bSizer2 = Wx::BoxSizer->new( Wx::wxVERTICAL );
 	$bSizer2->Add( $m_staticText1, 0, Wx::wxALL, 5 );
 	$bSizer2->Add( 10, 5, 1, Wx::wxEXPAND, 5 );
@@ -74,6 +91,8 @@ sub new {
 	$bSizer2->Add( $m_staticline1, 0, Wx::wxEXPAND | Wx::wxALL, 5 );
 	$bSizer2->Add( $self->{m_choice1}, 0, Wx::wxALL, 5 );
 	$bSizer2->Add( $self->{m_comboBox1}, 0, Wx::wxALL, 5 );
+	$bSizer2->Add( $self->{m_listBox1}, 0, Wx::wxALL, 5 );
+	$bSizer2->Add( $self->{m_listCtrl1}, 0, Wx::wxALL | Wx::wxEXPAND, 5 );
 
 	my $bSizer1 = Wx::BoxSizer->new( Wx::wxHORIZONTAL );
 	$bSizer1->Add( $bSizer2, 1, Wx::wxEXPAND, 5 );
